@@ -1,5 +1,7 @@
 # -*- coding: utf-8 -*-
+from dataclasses import dataclass, field
 import logging
+from typing import Optional
 
 from vindauga.constants.buttons import bfNormal, bfDefault
 from vindauga.constants.command_codes import cmOK, cmCancel
@@ -7,12 +9,14 @@ from vindauga.constants.colors import cmNewColorIndex, cmNewColorItem, cmSetColo
 from vindauga.constants.event_codes import evBroadcast
 from vindauga.constants.option_flags import ofCentered
 from vindauga.constants.key_mappings import showMarkers
+from vindauga.types.color_group import ColorGroup
+from vindauga.types.palette import Palette
 from vindauga.types.rect import Rect
 from vindauga.widgets.button import Button
 from vindauga.widgets.color_display import ColorDisplay
 from vindauga.widgets.color_group_list import ColorGroupList
 from vindauga.widgets.color_item_list import ColorItemList
-from vindauga.widgets.color_selector import ColorSelector
+from vindauga.widgets.color_selector import ColorSelector, ColorSel
 from vindauga.widgets.dialog import Dialog
 from vindauga.widgets.label import Label
 from vindauga.widgets.mono_selector import MonoSelector
@@ -20,12 +24,11 @@ from vindauga.widgets.scroll_bar import ScrollBar
 
 logger = logging.getLogger(__name__)
 
-
+@dataclass
 class ColorIndex:
-    def __init__(self):
-        self.groupIndex = 0
-        self.colorSize = 0
-        self.colorIndex = []
+    groupIndex: int = 0
+    colorSize: int = 0
+    colorIndex: list = field(default_factory=list)
 
 
 class ColorDialog(Dialog):
@@ -46,14 +49,15 @@ class ColorDialog(Dialog):
     okText = _('O~K~')
     cancelText = _('Cancel')
 
-    def __init__(self, palette, groups):
+    def __init__(self, palette: Optional[Palette], groups: ColorGroup):
         super().__init__(Rect(0, 0, 79, 18), self.colors)
         self.groupIndex = None
         self.colorIndexes = None
+        self._colorIndex = 0
 
         self.options |= ofCentered
         if palette:
-            self.pal = palette
+            self.pal = Palette(palette)
         else:
             self.pal = None
 
@@ -72,14 +76,14 @@ class ColorDialog(Dialog):
 
         self.insert(Label(Rect(30, 2, 36, 3), self.itemText, p))
 
-        self._forSel = ColorSelector(Rect(63, 3, 75, 7), ColorSelector.csForeground)
+        self._forSel = ColorSelector(Rect(63, 3, 75, 7), ColorSel.csForeground)
 
         self.insert(self._forSel)
 
         self._forLabel = Label(Rect(63, 2, 75, 3), self.forText, self._forSel)
         self.insert(self._forLabel)
 
-        self._bakSel = ColorSelector(Rect(63, 9, 75, 11), ColorSelector.csBackground)
+        self._bakSel = ColorSelector(Rect(63, 9, 75, 11), ColorSel.csBackground)
         self.insert(self._bakSel)
         self._bakLabel = Label(Rect(63, 8, 75, 9), self.bakText, self._bakSel)
         self.insert(self._bakLabel)
@@ -94,6 +98,9 @@ class ColorDialog(Dialog):
         self._monoLabel.hide()
         self.insert(self._monoLabel)
 
+        if groups and groups.items and self.pal:
+            self._display.setColor(self.pal[groups.index])
+
         self.insert(Button(Rect(51, 15, 61, 17), self.okText, cmOK, bfDefault))
         self.insert(Button(Rect(63, 15, 73, 17), self.cancelText, cmCancel, bfNormal))
         self.selectNext(False)
@@ -105,11 +112,14 @@ class ColorDialog(Dialog):
             if event.message.command == cmNewColorItem:
                 self.groupIndex = self._groups.focused
             elif event.message.command == cmSetColorIndex:
-                self.pal.palette[self._groups.getGroupIndex(self.groupIndex)] = event.message.infoPtr
-            elif event.message.command == cmNewColorIndex:
-                self._display.setColor(self.pal.palette[event.message.infoPtr])
+                self.pal.palette[self._colorIndex - 1] = event.message.infoPtr
+
         super().handleEvent(event)
 
+        if event.what == evBroadcast and event.message.command == cmNewColorIndex:
+            self._colorIndex = event.message.infoPtr
+            self._display.setColor(self.pal.palette[event.message.infoPtr])
+
     def consumesData(self):
         return True
 
@@ -120,16 +130,15 @@ class ColorDialog(Dialog):
         self.colorIndexes = self.getIndexes(self.colorIndexes)
         return self.pal
 
-    def setData(self, palette):
+    def setData(self, palette: Palette):
         """
         Sets the palette to the
 
         :param palette: A Palette
         """
-        self.pal = palette
+        self.pal = Palette(palette)
         self.colorIndexes = self.setIndexes(self.colorIndexes)
-
-        self._display.setColor(self.pal.palette[self._groups.getGroupIndex(self.groupIndex)])
+        self._display.setColor(palette.palette[self._groups.getGroupIndex(self.groupIndex)])
         self._groups.focusItem(self.groupIndex)
         if showMarkers:
             self._forLabel.hide()
@@ -138,10 +147,9 @@ class ColorDialog(Dialog):
             self._bakSel.hide()
             self._monoLabel.show()
             self._monoSel.show()
-
         self._groups.select()
 
-    def setIndexes(self, colorIndex):
+    def setIndexes(self, colorIndex: Optional[ColorIndex]) -> ColorIndex:
         numGroups = self._groups.getNumGroups()
 
         if colorIndex and (colorIndex.colorSize != numGroups):
@@ -158,12 +166,13 @@ class ColorDialog(Dialog):
         self.groupIndex = colorIndex.groupIndex
         return colorIndex
 
-    def getIndexes(self, colorIndex):
+    def getIndexes(self, colorIndex: Optional[ColorIndex] = None) -> ColorIndex:
         n = self._groups.getNumGroups()
 
         if not colorIndex:
             colorIndex = ColorIndex()
+            colorIndex.colorIndex = [0] * n
             colorIndex.colorSize = n
         colorIndex.groupIndex = self.groupIndex
-        colorIndex.colorIndex.extend(self._groups.groups)
+        colorIndex.colorIndex = [self._groups.getGroupIndex(index) for index in range(n)]
         return colorIndex
