@@ -1,19 +1,27 @@
 # -*- coding: utf-8 -*-
+from enum import IntEnum
 import logging
 
 from vindauga.constants.colors import cmColorForegroundChanged, cmColorBackgroundChanged, cmColorSet
 from vindauga.constants.event_codes import evBroadcast, evMouseDown, evKeyDown, evMouseMove
 from vindauga.constants.keys import kbLeft, kbRight, kbDown, kbUp
 from vindauga.constants.option_flags import ofSelectable, ofFirstClick, ofFramed
+from vindauga.events.event import Event
 from vindauga.misc.cp437 import cp437ToUnicode
 from vindauga.misc.message import message
 from vindauga.misc.util import ctrlToArrow
 from vindauga.types.draw_buffer import DrawBuffer
+from vindauga.types.rect import Rect
 from vindauga.types.view import View
 
 logger = logging.getLogger(__name__)
 
 
+class ColorSel(IntEnum):
+    csBackground = 0
+    csForeground = 1
+
+
 class ColorSelector(View):
     """
     The interrelated classes `ColorItem`, `ColorGroup`, `ColorSelector`,
@@ -24,13 +32,11 @@ class ColorSelector(View):
 
     `ColorSelector` is a view for displaying the color selections available.
     """
-    csBackground = 0
-    csForeground = 1
     icon = '○'
     icon_reversed = '◙'
     name = 'ColorSelector'
 
-    def __init__(self, bounds, selectorType):
+    def __init__(self, bounds: Rect, selectorType: ColorSel):
         super().__init__(bounds)
         self.options |= (ofSelectable | ofFirstClick | ofFramed)
         self.eventMask |= evBroadcast
@@ -52,7 +58,7 @@ class ColorSelector(View):
 
             self.writeLine(0, y, self.size.x, 1, b)
 
-    def handleEvent(self, event):
+    def handleEvent(self, event: Event):
         """
         Handles mouse and key events: you can click on a given color indicator
         to select that color, or you can select colors by positioning the
@@ -74,7 +80,8 @@ class ColorSelector(View):
         elif what == evKeyDown:
             key = ctrlToArrow(event.keyDown.keyCode)
             if key in {kbLeft, kbRight, kbUp, kbDown}:
-                self.__handleKeyDownEvent(key, maxCol, width)
+                if self.__handleKeyDownEvent(key, maxCol, width):
+                    self.clearEvent(event)
         elif what == evBroadcast:
             self.__handleBroadcastEvent(event)
 
@@ -82,19 +89,19 @@ class ColorSelector(View):
         """
         Send a message to indicate color has changed
         """
-        if self._selectorType == self.csForeground:
+        if self._selectorType == ColorSel.csForeground:
             msg = cmColorForegroundChanged
         else:
             msg = cmColorBackgroundChanged
 
         message(self.owner, evBroadcast, msg, self._color)
 
-    def __handleBroadcastEvent(self, event):
+    def __handleBroadcastEvent(self, event: Event):
         if event.message.command == cmColorSet:
-            if self._selectorType == self.csBackground:
-                self._color = ord(event.message.infoPtr) >> 4
+            if self._selectorType == ColorSel.csBackground:
+                self._color = event.message.infoPtr >> 4
             else:
-                self._color = ord(event.message.infoPtr) & 0x0f
+                self._color = event.message.infoPtr & 0x0f
             self.drawView()
 
     def __handleKeyDownEvent(self, key, maxCol, width):
@@ -122,8 +129,11 @@ class ColorSelector(View):
                 self._color = 0
             else:
                 self._color -= maxCol - width
+        else:
+            return
         self.__colorChanged()
         self.drawView()
+        return True
 
     def __handleMouseEvent(self, event, oldColor):
         mousing = True
@@ -136,4 +146,6 @@ class ColorSelector(View):
             self.__colorChanged()
             self.drawView()
             mousing = self.mouseEvent(event, evMouseMove)
-
+        self.__colorChanged()
+        self.drawView()
+        self.clearEvent(event)
