@@ -3,6 +3,7 @@ import curses
 import logging
 
 from vindauga.constants.grow_flags import gfGrowHiX, gfGrowHiY
+from vindauga.types.screen import Screen
 from vindauga.utilities.ansify import wallpaper
 from vindauga.types.draw_buffer import DrawBuffer
 from vindauga.types.palette import Palette
@@ -27,15 +28,14 @@ class Wallpaper(View):
         self._wpWidth, self._wpHeight, self._wallpaper = wallpaper(filename, bounds)
         self.growMode = gfGrowHiX | gfGrowHiY
 
-
     def draw(self):
-        size = self.getBounds()
-
-        vOffset = (size.height - self._wpHeight) // 2
-        hOffset = (size.width - self._wpWidth) // 2
-        logger.info('wp: (%s, %s)', self._wpWidth, self._wpHeight)
-        for y, line in enumerate(self._wallpaper):
-            self.writeLine(hOffset, vOffset + y, self._wpWidth, 1, line)
+        with Screen.setRawMode():
+            size = self.getBounds()
+            vOffset = (size.height - self._wpHeight) // 2
+            hOffset = (size.width - self._wpWidth) // 2
+            logger.info('wp: (%s, %s)', self._wpWidth, self._wpHeight)
+            for y, line in enumerate(self._wallpaper):
+                self.writeLine(hOffset, vOffset + y, self._wpWidth, 1, line)
 
     def getPalette(self):
         palette = Palette(self.cpBackground)
