@@ -1,4 +1,6 @@
 # -*- coding: utf-8 -*-
+import itertools
+import logging
 import os
 import sys
 
@@ -45,6 +47,9 @@ from vindauga.widgets.radio_buttons import RadioButtons
 from vindauga.widgets.static_text import StaticText
 from vindauga.widgets.status_line import StatusLine
 
+logger = logging.getLogger('vindauga.vindauga_demp')
+
+
 checkBoxData = 0
 radioButtonData = 0
 inputLineData = ''
@@ -52,6 +57,16 @@ inputLineData = ''
 demoDialogData = reversed([checkBoxData, radioButtonData, inputLineData])
 
 
+def setupLogging():
+    logger = logging.getLogger('vindauga')
+    logger.propagate = False
+    format = '%(name)s\t %(message)s'
+    logger.setLevel(logging.DEBUG)
+    handler = logging.StreamHandler(open('vindauga.log', 'wt'))
+    handler.setFormatter(logging.Formatter(format))
+    logger.addHandler(handler)
+
+
 class VindaugaDemo(Application):
     def __init__(self):
         super().__init__()
@@ -361,7 +376,8 @@ class VindaugaDemo(Application):
             c.helpCtx = HelpContexts.hcOCColorsDBox
             c.setData(self.getPalette())
             if self.desktop.execView(c) != cmCancel:
-                self.setPalette(c.pal)
+                pal = c.getData()
+                self.setPalette(pal)
                 self.setScreenMode(Screen.screenMode)
         self.destroy(c)
 
@@ -392,17 +408,8 @@ def run():
 
 
 if __name__ == '__main__':
-    import logging
-
-    logger = logging.getLogger('vindauga')
-    logger.propagate = False
-    format = '%(name)s\t %(message)s'
-    logger.setLevel(logging.DEBUG)
-    handler = logging.StreamHandler(open('vindauga.log', 'wt'))
-    handler.setFormatter(logging.Formatter(format))
-    logger.addHandler(handler)
+    setupLogging()
     try:
         run()
     except:
         logger.exception('vindauga fail')
-
